@@ -28,8 +28,10 @@ public:
     LanguageToolGrammarError();
     ~LanguageToolGrammarError() override;
     void parse(const QJsonObject &obj, int blockindex) override;
+    void setTesting(bool b);
 private:
     static QStringList parseSuggestion(const QJsonObject &obj);
+    bool mTesting = false;
 };
 Q_DECLARE_METATYPE(LanguageToolGrammarError)
 Q_DECLARE_TYPEINFO(LanguageToolGrammarError, Q_MOVABLE_TYPE);
