@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -59,9 +59,9 @@ void BriefHeaderStylePluginTest::testFormatEmpty()
 {
     MessageViewer::BriefHeaderStylePlugin plugin;
     auto style = plugin.headerStyle();
-    auto stategy = plugin.headerStrategy();
-    style->setHeaderStrategy(stategy);
-    QCOMPARE(style->headerStrategy(), stategy);
+    auto strategy = plugin.headerStrategy();
+    style->setHeaderStrategy(strategy);
+    QCOMPARE(style->headerStrategy(), strategy);
     auto aMsg = new KMime::Message();
     testHeaderFile(style->format(aMsg), QStringLiteral("empty.brief"));
 }
@@ -83,9 +83,9 @@ void BriefHeaderStylePluginTest::testFormat()
 
     MessageViewer::BriefHeaderStylePlugin plugin;
     auto style = plugin.headerStyle();
-    auto stategy = plugin.headerStrategy();
-    style->setHeaderStrategy(stategy);
-    QCOMPARE(style->headerStrategy(), stategy);
+    auto strategy = plugin.headerStrategy();
+    style->setHeaderStrategy(strategy);
+    QCOMPARE(style->headerStrategy(), strategy);
     auto aMsg = readAndParseMail(mailbox);
     testHeaderFile(style->format(aMsg.data()), mailbox+QStringLiteral(".brief"));
 }
