@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -50,11 +50,11 @@ EventEdit::EventEdit(QWidget *parent)
     : QWidget(parent)
 {
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setMargin(5);
+    vbox->setContentsMargins(5, 5, 5, 5);
     vbox->setSpacing(2);
 
     QHBoxLayout *hbox = new QHBoxLayout;
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setSpacing(2);
     vbox->addLayout(hbox);
 
@@ -87,7 +87,7 @@ EventEdit::EventEdit(QWidget *parent)
     hbox->addWidget(mCollectionCombobox);
 
     hbox = new QHBoxLayout;
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setSpacing(2);
     vbox->addLayout(hbox);
 
@@ -122,7 +122,7 @@ EventEdit::EventEdit(QWidget *parent)
 
     hbox = new QHBoxLayout;
     hbox->setSpacing(2);
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     vbox->addLayout(hbox);
 
     hbox->addStretch(1);
