@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -49,7 +49,7 @@ TodoEdit::TodoEdit(QWidget *parent)
     : QWidget(parent)
 {
     QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setMargin(5);
+    vbox->setContentsMargins(5, 5, 5, 5);
     vbox->setSpacing(2);
 
     mMsgWidget = new KMessageWidget(this);
@@ -61,7 +61,7 @@ TodoEdit::TodoEdit(QWidget *parent)
     vbox->addWidget(mMsgWidget);
 
     QHBoxLayout *hbox = new QHBoxLayout;
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setSpacing(2);
     vbox->addLayout(hbox);
 
@@ -93,7 +93,7 @@ TodoEdit::TodoEdit(QWidget *parent)
     hbox->addWidget(mCollectionCombobox);
 
     hbox = new QHBoxLayout;
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setSpacing(2);
     vbox->addLayout(hbox);
 
